"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeUpdater = makeUpdater;
exports.updateAndSave = updateAndSave;

var _fslib = require("@yarnpkg/fslib");

var _makeTracker = require("./makeTracker");

async function makeUpdater(filename) {
  let indent = `  `;
  let obj;

  if (_fslib.xfs.existsSync(filename)) {
    const content = await _fslib.xfs.readFilePromise(filename, `utf8`);
    const indentMatch = content.match(/^[ \t]+/m);
    if (indentMatch) indent = indentMatch[0];
    obj = JSON.parse(content || `{}`);
  }

  if (!obj) obj = {};
  const tracker = (0, _makeTracker.makeTracker)(obj);
  const initial = tracker.immutable;
  return {
    open(cb) {
      tracker.open(cb);
    },

    async save() {
      if (tracker.immutable === initial) return;
      const data = `${JSON.stringify(tracker.immutable, null, indent)}\n`;
      await _fslib.xfs.writeFilePromise(filename, data);
    }

  };
}

async function updateAndSave(filename, cb) {
  const updater = await makeUpdater(filename);
  updater.open(cb);
  await updater.save();
}